"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = send;

var _colors = _interopRequireDefault(require("colors"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _oscMin = _interopRequireDefault(require("osc-min"));

var _createSocket = _interopRequireDefault(require("./createSocket.js"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-constant-condition: 0 */

/* eslint no-await-in-loop: 0 */
_inquirer.default.registerPrompt('command', require('inquirer-command-prompt'));

function parseInputValue(value) {
  if (/^".+"$/.test(value) === true) {
    return value;
  } else if (/\./.test(value)) {
    return parseFloat(value);
  } else {
    return parseInt(value);
  }
}

async function sendMessage(socket, message, port) {
  return new Promise((resolve, reject) => {
    socket.send(message, 0, message.length, port, err => {
      if (err) {
        reject(err);
      } else {
        resolve();
      }
    });
  });
}

async function send(port) {
  try {
    const socket = await (0, _createSocket.default)();
    console.log(`\nUse the following format to send messages:\n`.yellow.bold);
    console.log(`<address> <value>\n`);
    console.log(`<address> is written out plain and simple`.gray);
    console.log(`<value> is either a number or a string wrapped in double quotes\n`.gray);
    console.log(`Example: /light/1/color "red"`.gray);

    while (true) {
      const {
        input
      } = await _inquirer.default.prompt([{
        type: 'command',
        name: 'input',
        message: '>'
      }]);
      const [address, rawValue] = input.split(' ');
      const value = parseInputValue(rawValue);

      const message = _oscMin.default.toBuffer({
        address,
        args: [value]
      });

      await sendMessage(socket, message, port);
    }
  } catch (err) {
    throw err;
  }
}